# Welcome to XYZ_Project!
**Home of cats, dreams, and interpretable neural networks.**

(Name may change before public release.)

XYZ_Project is a collection of infrastructure and tools for research in neural network interpretability. 

In particular, it provides state of the art implementations of [feature visualization techniques](), and flexible abstractions that make it very easy to explore new research directions.

Quick start: [dXYZ_Project-tutorial]() (TODO)

How XYZ_Project is structured:

* [**modelzoo**]():
  Easily import models for visualization
* [**optvis**]():
  Framework for optimization-based [feature visualization](https://distill.pub/2017/feature-visualization/)
* [**scratch**]():
  Incubating code that needs to be shared between notebooks.
* [**misc**]():
  More mature code that doesn't fit into a large cluster.
* [**recipes**]():
  Less general code that makes a particular visualization.

Note that we do a lot of our research in colab notebooks and transition code here as it matures.




# License and Disclaimer

You may use this software under the Apache 2.0 License. See [LICENSE](LICENSE).

This project is research code. It is not an official Google product. 
